colour_hdri.models Package — Colour - HDRI 0.1.0 documentation

# colour_hdri.models Package

## Sub-Modules

- colour_hdri.models.rgb Module
  - RGB Colourspace & Transformations

## Module Contents

`colour_hdri.models.` `camera_space_to_RGB`(RGB, XYZ_to_camera_matrix, RGB_to_XYZ_matrix)

  Converts given RGB array from camera space to given RGB colourspace.

  Parameters: | RGB (array_like) – Camera space RGB colourspace array. XYZ_to_camera_matrix (array_like) – Matrix converting from CIE XYZ tristimulus values to camera space. RGB_to_XYZ_matrix (array_like) – Matrix converting from RGB colourspace to CIE XYZ tristimulus values.
  Returns: | RGB colourspace array.
  Return type: | ndarray

  Examples

      >>> RGB = np.array([0.80660, 0.81638, 0.65885])
      >>> XYZ_to_camera_matrix = np.array([
      ...     [0.47160000, 0.06030000, -0.08300000],
      ...     [-0.77980000, 1.54740000, 0.24800000],
      ...     [-0.14960000, 0.19370000, 0.66510000]])
      >>> RGB_to_XYZ_matrix = np.array([
      ...     [0.41238656, 0.35759149, 0.18045049],
      ...     [0.21263682, 0.71518298, 0.07218020],
      ...     [0.01933062, 0.11919716, 0.95037259]])
      >>> camera_space_to_RGB(
      ...     RGB,
      ...     XYZ_to_camera_matrix,
      ...     RGB_to_XYZ_matrix)
      array([ 0.7564180...,  0.8683192...,  0.6044589...])

`colour_hdri.models.` `camera_space_to_sRGB`(RGB, XYZ_to_camera_matrix)

  Converts given RGB array from camera space to sRGB colourspace.

  Parameters: | RGB (array_like) – Camera space RGB colourspace array. XYZ_to_camera_matrix (array_like) – Matrix converting from CIE XYZ tristimulus values to camera space.
  Returns: | sRGB colourspace array.
  Return type: | ndarray

  Examples

      >>> RGB = np.array([0.80660, 0.81638, 0.65885])
      >>> XYZ_to_camera_matrix = np.array([
      ...     [0.47160000, 0.06030000, -0.08300000],
      ...     [-0.77980000, 1.54740000, 0.24800000],
      ...     [-0.14960000, 0.19370000, 0.66510000]])
      >>> camera_space_to_sRGB(RGB, XYZ_to_camera_matrix)
      array([ 0.7564180...,  0.8683192...,  0.6044589...])